Struct imdb_async::Episode [−][src]
pub struct Episode {
pub season: u16,
pub episode: u16,
pub imdb_id: u64,
pub title: String,
pub runtime_minutes: Option<u16>,
}Expand description
Represents an episode of a TV series from IMDB. Pared down from Title and EpisodeLink based on fields that make sense for an individual episode.
Fields
season: u16episode: u16imdb_id: u64title: Stringruntime_minutes: Option<u16>Trait Implementations
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more